@@ -1044,7 +1044,7 @@ sub todo_tests_default {
 	# solaris also. I suspected nvx<=>cop_seq_*
 	push @todo, (12)    if $^O eq 'MSWin32' and $Config{cc} =~ /^cl/i;
 	push @todo, (26)    if $what =~ /^cc_o[12]/;
-        push @todo, (27)    if $] > 5.008008 and $] < 5.009 and !$ITHREADS;
+        push @todo, (27)    if $] > 5.008008 and $] < 5.009;
 	push @todo, (27)    if $] > 5.008008 and $] < 5.009 and $what eq 'cc_o2';
         push @todo, (103)   if ($] >= 5.012 and $] < 5.014 and !$ITHREADS);
         push @todo, (12,19,25) if $] >= 5.019;
